@@ -143,7 +143,7 @@ func isModified(cwd, redoDir, tgt string) (bool, *Inode, error) {
 			}
 			return false, nil, err
 		}
-		if m["Target"] != tgt {
+		if m["Type"] != DepTypeIfchange || m["Target"] != tgt {
 			continue
 		}
 		fd, err := os.Open(path.Join(cwd, tgt))
